==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/worldpay.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	worldpay.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_WORLDPAY_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_WORLDPAY_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_WORLDPAY_ID_DESC' => 'Your WorldPay Select Junior ID',
	'MODULE_PAYMENT_WORLDPAY_ID_TITLE' => 'Worldpay Installation ID',
	'MODULE_PAYMENT_WORLDPAY_MD5KEY_DESC' => 'Use MD5 encyption for transactions? (1 = Yes, 0 = No)',
	'MODULE_PAYMENT_WORLDPAY_MD5KEY_TITLE' => 'Use MD5',
	'MODULE_PAYMENT_WORLDPAY_MODE_DESC' => 'The mode you are working in (100 = Test Mode Accept, 101 = Test Mode Decline, 0 = Live',
	'MODULE_PAYMENT_WORLDPAY_MODE_TITLE' => 'Mode',
	'MODULE_PAYMENT_WORLDPAY_ORDER_STATUS_ID_DESC' => 'Set the status of orders made with this payment module to this value',
	'MODULE_PAYMENT_WORLDPAY_ORDER_STATUS_ID_TITLE' => 'Set Order Status',
	'MODULE_PAYMENT_WORLDPAY_PREAUTH_DESC' => 'The mode you are working in (A = Pay Now, E = Pre Auth). Ignored if Use PreAuth is False.',
	'MODULE_PAYMENT_WORLDPAY_PREAUTH_TITLE' => 'Pre-Auth',
	'MODULE_PAYMENT_WORLDPAY_SORT_ORDER_DESC' => 'Sort order of display. Lowest is displayed first.',
	'MODULE_PAYMENT_WORLDPAY_SORT_ORDER_TITLE' => 'Sort order of display.',
	'MODULE_PAYMENT_WORLDPAY_STATUS_DESC' => 'Do you want to accept WorldPay payments?',
	'MODULE_PAYMENT_WORLDPAY_STATUS_TITLE' => 'Enable WorldPay Module',
	'MODULE_PAYMENT_WORLDPAY_TEXT_DESC' => 'Worldpay Payment Module',
	'MODULE_PAYMENT_WORLDPAY_TEXT_INFO' => '',
	'MODULE_PAYMENT_WORLDPAY_TEXT_TITLE' => 'Secure Credit Card Payment',
	'MODULE_PAYMENT_WORLDPAY_USEMD5_DESC' => 'Use MD5 encyption for transactions? (1 = Yes, 0 = No)',
	'MODULE_PAYMENT_WORLDPAY_USEMD5_TITLE' => 'Use MD5',
	'MODULE_PAYMENT_WORLDPAY_USEPREAUTH_DESC' => 'Do you want to pre-authorise payments? Default=False. You need to request this from WorldPay before using it.',
	'MODULE_PAYMENT_WORLDPAY_USEPREAUTH_TITLE' => 'Use Pre-Authorisation?',
	'MODULE_PAYMENT_WORLDPAY_ZONE_DESC' => 'If a zone is selected, only enable this payment method for that zone.',
	'MODULE_PAYMENT_WORLDPAY_ZONE_TITLE' => 'Payment Zone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/worldpay.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	worldpay.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_WORLDPAY_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_WORLDPAY_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_WORLDPAY_ID_DESC' => 'Your WorldPay Select Junior ID',
	'MODULE_PAYMENT_WORLDPAY_ID_TITLE' => 'Worldpay Installation ID',
	'MODULE_PAYMENT_WORLDPAY_MD5KEY_DESC' => 'Use MD5 encyption for transactions? (1 = Yes, 0 = No)',
	'MODULE_PAYMENT_WORLDPAY_MD5KEY_TITLE' => 'Use MD5',
	'MODULE_PAYMENT_WORLDPAY_MODE_DESC' => 'The mode you are working in (100 = Test Mode Accept, 101 = Test Mode Decline, 0 = Live',
	'MODULE_PAYMENT_WORLDPAY_MODE_TITLE' => 'Mode',
	'MODULE_PAYMENT_WORLDPAY_ORDER_STATUS_ID_DESC' => 'Set the status of orders made with this payment module to this value',
	'MODULE_PAYMENT_WORLDPAY_ORDER_STATUS_ID_TITLE' => 'Set Order Status',
	'MODULE_PAYMENT_WORLDPAY_PREAUTH_DESC' => 'The mode you are working in (A = Pay Now, E = Pre Auth). Ignored if Use PreAuth is False.',
	'MODULE_PAYMENT_WORLDPAY_PREAUTH_TITLE' => 'Pre-Auth',
	'MODULE_PAYMENT_WORLDPAY_SORT_ORDER_DESC' => 'Sort order of display. Lowest is displayed first.',
	'MODULE_PAYMENT_WORLDPAY_SORT_ORDER_TITLE' => 'Sort order of display.',
	'MODULE_PAYMENT_WORLDPAY_STATUS_DESC' => 'Do you want to accept WorldPay payments?',
	'MODULE_PAYMENT_WORLDPAY_STATUS_TITLE' => 'Enable WorldPay Module',
	'MODULE_PAYMENT_WORLDPAY_TEXT_DESC' => 'Worldpay Payment Module',
	'MODULE_PAYMENT_WORLDPAY_TEXT_INFO' => '',
	'MODULE_PAYMENT_WORLDPAY_TEXT_TITLE' => 'Secure Credit Card Payment',
	'MODULE_PAYMENT_WORLDPAY_USEMD5_DESC' => 'Use MD5 encyption for transactions? (1 = Yes, 0 = No)',
	'MODULE_PAYMENT_WORLDPAY_USEMD5_TITLE' => 'Use MD5',
	'MODULE_PAYMENT_WORLDPAY_USEPREAUTH_DESC' => 'Do you want to pre-authorise payments? Default=False. You need to request this from WorldPay before using it.',
	'MODULE_PAYMENT_WORLDPAY_USEPREAUTH_TITLE' => 'Use Pre-Authorisation?',
	'MODULE_PAYMENT_WORLDPAY_ZONE_DESC' => 'If a zone is selected, only enable this payment method for that zone.',
	'MODULE_PAYMENT_WORLDPAY_ZONE_TITLE' => 'Payment Zone'
);
